@@ -213,7 +213,7 @@ sub _schedule_packages {
 	    $pkg->update_header($mode->{$_}, keep_all_tags => 1);
 	    my ($true_rpm, $true_pkg);
 	    if ($pkg->payload_format eq 'drpm') { #- handle deltarpms
-		($true_rpm, $true_pkg) = _apply_delta_rpm($urpm, $mode->{$_}, $mode, $pkg);
+		($true_rpm, $true_pkg) = _apply_delta_rpm($urpm, $_, $mode, $pkg);
 		push @produced_deltas, ($mode->{$_} = $true_rpm); #- fix path
 	    }
 	    if ($trans->add($true_pkg || $pkg, update => $update,
@@ -348,7 +348,7 @@ sub install {
 	    }
 	}
 
-	if ($options{verbose} >= 0 && !$options{justdb}) {
+	if ($options{verbose} >= 0) {
 	    foreach (keys %{$urpm->{readmes}}) {
 		$urpm->{print}("-" x 70 .  "\n" .
                                  N("More information on package %s", $urpm->{readmes}{$_}));
